@@ -483,7 +483,7 @@ def get_thumbnail(config: Configuration, video_id: str, video: Dict[str, Any]) -
     publish_image = f"{video_id}.jpg"
     publish_image_path = f"{config.publish_dir}/{config.media_dir}/{publish_image}"
     if not os.path.isfile(publish_image_path):
-        remote_image = requests.get(image_url)
+        remote_image = requests.get(url=image_url, timeout=5)
         with open(local_image, "wb") as file:
             file.write(remote_image.content)
         thumbnail_wip = Image.open(local_image)
